@@ -30,6 +30,12 @@ class TestBindings(TestCase):
         # directly in the test, not in test/SolverInterface.hpp
         self.assertEqual(fake_dimension, solver_interface.get_dimensions())
 
+    def test_is_mesh_connectivity_required(self):
+        solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
+        fake_bool = 0  # compare to output in test/SolverInterface.cpp
+        fake_mesh_id = 0
+        self.assertEqual(fake_bool, solver_interface.is_mesh_connectivity_required(fake_mesh_id))
+
     def test_get_mesh_id(self):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         # TODO: it would be nice to be able to mock the output of the interface
@@ -45,8 +51,7 @@ class TestBindings(TestCase):
         n_fake_vertices = 3  # compare to test/SolverInterface.cpp, n_fake_vertices
         positions = np.random.rand(n_fake_vertices, fake_dimension)
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertices_empty(self):
@@ -56,8 +61,7 @@ class TestBindings(TestCase):
         n_fake_vertices = 0  # compare to test/SolverInterface.cpp, n_fake_vertices
         positions = np.random.rand(n_fake_vertices, fake_dimension)
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertices_list(self):
@@ -69,8 +73,7 @@ class TestBindings(TestCase):
         positions = list(list(positions[i, j] for j in range(
             positions.shape[1])) for i in range(positions.shape[0]))
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertices_empty_list(self):
@@ -79,8 +82,7 @@ class TestBindings(TestCase):
         positions = []
         n_fake_vertices = 0
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertices_tuple(self):
@@ -92,8 +94,7 @@ class TestBindings(TestCase):
         positions = tuple(tuple(positions[i, j] for j in range(
             positions.shape[1])) for i in range(positions.shape[0]))
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertices_empty_tuple(self):
@@ -102,8 +103,7 @@ class TestBindings(TestCase):
         positions = ()
         n_fake_vertices = 0
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertices_mixed(self):
@@ -115,8 +115,7 @@ class TestBindings(TestCase):
         positions = list(tuple(positions[i, j] for j in range(
             positions.shape[1])) for i in range(positions.shape[0]))
         expected_output = np.array(range(n_fake_vertices))
-        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id,
-                                                           positions)
+        actual_output = solver_interface.set_mesh_vertices(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(expected_output, actual_output))
 
     def test_set_mesh_vertex(self):
@@ -172,8 +171,7 @@ class TestBindings(TestCase):
         n_fake_vertices = 3  # compare to test/SolverInterface.cpp, n_fake_vertices
         positions = np.random.rand(n_fake_vertices, fake_dimension)
         fake_vertex_ids = range(n_fake_vertices)
-        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(
-            fake_mesh_id, positions)
+        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(fake_vertex_ids, vertex_ids))
 
     def test_get_mesh_vertex_ids_from_positions_list(self):
@@ -185,8 +183,7 @@ class TestBindings(TestCase):
         positions = list(list(positions[i, j] for j in range(
             positions.shape[1])) for i in range(positions.shape[0]))
         fake_vertex_ids = range(n_fake_vertices)
-        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(
-            fake_mesh_id, positions)
+        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(fake_vertex_ids, vertex_ids))
 
     def test_get_mesh_vertex_ids_from_positions_tuple(self):
@@ -198,8 +195,7 @@ class TestBindings(TestCase):
         positions = tuple(tuple(positions[i, j] for j in range(
             positions.shape[1])) for i in range(positions.shape[0]))
         fake_vertex_ids = range(n_fake_vertices)
-        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(
-            fake_mesh_id, positions)
+        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(fake_vertex_ids, vertex_ids))
 
     def test_get_mesh_vertex_ids_from_positions_mixed(self):
@@ -211,8 +207,7 @@ class TestBindings(TestCase):
         positions = list(tuple(positions[i, j] for j in range(
             positions.shape[1])) for i in range(positions.shape[0]))
         fake_vertex_ids = range(n_fake_vertices)
-        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(
-            fake_mesh_id, positions)
+        vertex_ids = solver_interface.get_mesh_vertex_ids_from_positions(fake_mesh_id, positions)
         self.assertTrue(np.array_equal(fake_vertex_ids, vertex_ids))
 
     def test_get_mesh_vertex_size(self):
@@ -232,17 +227,14 @@ class TestBindings(TestCase):
             fake_vertices[i, 0] = i
             fake_vertices[i, 1] = i + n_fake_vertices
             fake_vertices[i, 2] = i + 2 * n_fake_vertices
-        vertices = solver_interface.get_mesh_vertices(fake_mesh_id,
-                                                      range(n_fake_vertices))
+        vertices = solver_interface.get_mesh_vertices(fake_mesh_id, range(n_fake_vertices))
         self.assertTrue(np.array_equal(fake_vertices, vertices))
 
     def test_read_write_block_scalar_data(self):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         write_data = np.array([3, 7, 8], dtype=np.double)
-        solver_interface.write_block_scalar_data(
-            1, np.array([1, 2, 3]), write_data)
-        read_data = solver_interface.read_block_scalar_data(
-            1, np.array([1, 2, 3]))
+        solver_interface.write_block_scalar_data(1, np.array([1, 2, 3]), write_data)
+        read_data = solver_interface.read_block_scalar_data(1, np.array([1, 2, 3]))
         self.assertTrue(np.array_equal(write_data, read_data))
 
     def test_read_write_block_scalar_data_single_float(self):
@@ -269,11 +261,9 @@ class TestBindings(TestCase):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         dummy_array = np.random.rand(3, 3)
         write_data = dummy_array[:, 1]
-        assert(write_data.flags["C_CONTIGUOUS"] == False)
-        solver_interface.write_block_scalar_data(
-            1, np.array([1, 2, 3]), write_data)
-        read_data = solver_interface.read_block_scalar_data(
-            1, np.array([1, 2, 3]))
+        assert(write_data.flags["C_CONTIGUOUS"] is False)
+        solver_interface.write_block_scalar_data(1, np.array([1, 2, 3]), write_data)
+        read_data = solver_interface.read_block_scalar_data(1, np.array([1, 2, 3]))
         self.assertTrue(np.array_equal(write_data, read_data))
 
     def test_read_write_scalar_data(self):
@@ -287,10 +277,8 @@ class TestBindings(TestCase):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         write_data = np.array([[3, 7, 8],
                                [7, 6, 5]], dtype=np.double)
-        solver_interface.write_block_vector_data(
-            1, np.array([1, 2]), write_data)
-        read_data = solver_interface.read_block_vector_data(
-            1, np.array([1, 2]))
+        solver_interface.write_block_vector_data(1, np.array([1, 2]), write_data)
+        read_data = solver_interface.read_block_vector_data(1, np.array([1, 2]))
         self.assertTrue(np.array_equal(write_data, read_data))
 
     def test_read_write_block_vector_data_empty(self):
@@ -303,28 +291,22 @@ class TestBindings(TestCase):
     def test_read_write_block_vector_data_list(self):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         write_data = [[3, 7, 8], [7, 6, 5]]
-        solver_interface.write_block_vector_data(
-            1, np.array([1, 2]), write_data)
-        read_data = solver_interface.read_block_vector_data(
-            1, np.array([1, 2]))
+        solver_interface.write_block_vector_data(1, np.array([1, 2]), write_data)
+        read_data = solver_interface.read_block_vector_data(1, np.array([1, 2]))
         self.assertTrue(np.array_equal(write_data, read_data))
 
     def test_read_write_block_vector_data_tuple(self):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         write_data = ((3, 7, 8), (7, 6, 5))
-        solver_interface.write_block_vector_data(
-            1, np.array([1, 2]), write_data)
-        read_data = solver_interface.read_block_vector_data(
-            1, np.array([1, 2]))
+        solver_interface.write_block_vector_data(1, np.array([1, 2]), write_data)
+        read_data = solver_interface.read_block_vector_data(1, np.array([1, 2]))
         self.assertTrue(np.array_equal(write_data, read_data))
 
     def test_read_write_block_vector_data_mixed(self):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         write_data = [(3, 7, 8), (7, 6, 5)]
-        solver_interface.write_block_vector_data(
-            1, np.array([1, 2]), write_data)
-        read_data = solver_interface.read_block_vector_data(
-            1, np.array([1, 2]))
+        solver_interface.write_block_vector_data(1, np.array([1, 2]), write_data)
+        read_data = solver_interface.read_block_vector_data(1, np.array([1, 2]))
         self.assertTrue(np.array_equal(write_data, read_data))
 
     def test_read_write_block_vector_data_non_contiguous(self):
@@ -337,7 +319,7 @@ class TestBindings(TestCase):
         size = 6
         dummy_array = np.random.rand(size, 5)
         write_data = dummy_array[:, 1:4]
-        assert(write_data.flags["C_CONTIGUOUS"] == False)
+        assert(write_data.flags["C_CONTIGUOUS"] is False)
         vertex_ids = np.arange(size)
         solver_interface.write_block_vector_data(1, vertex_ids, write_data)
         read_data = solver_interface.read_block_vector_data(1, vertex_ids)
@@ -373,7 +355,7 @@ class TestBindings(TestCase):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         dummy_array = np.random.rand(3, 3)
         write_data = dummy_array[:, 1]
-        assert(write_data.flags["C_CONTIGUOUS"] == False)
+        assert(write_data.flags["C_CONTIGUOUS"] is False)
         solver_interface.write_vector_data(1, 1, write_data)
         read_data = solver_interface.read_vector_data(1, 1)
         self.assertTrue(np.array_equal(write_data, read_data))
@@ -382,9 +364,9 @@ class TestBindings(TestCase):
         solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
         fake_mesh_id = 0  # compare to test/SolverInterface.cpp, fake_mesh_id
         fake_data_name = "FakeData"  # compare to test/SolverInterface.cpp, fake_data_name
-        fake_data_ID = 15  # compare to test/SolverInterface.cpp, fake_data_ID
-        data_ID = solver_interface.get_data_id(fake_data_name, fake_mesh_id)
-        self.assertTrue(data_ID == fake_data_ID)
+        fake_data_id = 15  # compare to test/SolverInterface.cpp, fake_data_ID
+        data_id = solver_interface.get_data_id(fake_data_name, fake_mesh_id)
+        self.assertTrue(data_id == fake_data_id)
 
     def test_get_version_information(self):
         version_info = precice.get_version_information()
@@ -393,8 +375,7 @@ class TestBindings(TestCase):
 
     def test_action_write_initial_data(self):
         return_constant = precice.action_write_initial_data()
-        # compare to test/SolverInterface.cpp
-        dummy_constant = b"dummy_write_initial_data"
+        dummy_constant = b"dummy_write_initial_data"  # compare to test/SolverInterface.cpp
         self.assertEqual(return_constant, dummy_constant)
 
     def test_action_write_iteration_checkpoint(self):
@@ -406,3 +387,25 @@ class TestBindings(TestCase):
         return_constant = precice.action_read_iteration_checkpoint()
         dummy_constant = b"dummy_read_iteration"  # compare to test/SolverInterface.cpp
         self.assertEqual(return_constant, dummy_constant)
+
+    def test_set_mesh_access_region(self):
+        solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
+        fake_mesh_id = 0  # compare to test/SolverInterface.cpp, fake_mesh_id
+        fake_dimension = 3  # compare to test/SolverInterface.cpp, fake_dimensions
+        fake_bounding_box = np.arange(fake_dimension * 2)
+        solver_interface.set_mesh_access_region(fake_mesh_id, fake_bounding_box)
+
+    def test_get_mesh_vertices_and_ids(self):
+        solver_interface = precice.Interface("test", "dummy.xml", 0, 1)
+        fake_mesh_id = 0  # compare to test/SolverInterface.cpp, fake_mesh_id
+        n_fake_vertices = 3  # compare to test/SolverInterface.cpp, n_fake_vertices
+        fake_dimension = 3  # compare to test/SolverInterface.cpp, fake_dimensions
+        vertex_ids = np.arange(n_fake_vertices)
+        coordinates = np.zeros((n_fake_vertices, fake_dimension))
+        for i in range(n_fake_vertices):
+            coordinates[i, 0] = i * fake_dimension
+            coordinates[i, 1] = i * fake_dimension + 1
+            coordinates[i, 2] = i * fake_dimension + 2
+        fake_ids, fake_coordinates = solver_interface.get_mesh_vertices_and_ids(fake_mesh_id)
+        self.assertTrue(np.array_equal(fake_ids, vertex_ids))
+        self.assertTrue(np.array_equal(fake_coordinates, coordinates))
